@@ -9,5 +9,5 @@ class PinForm(ModelForm):
 class PinUpdateForm(ModelForm):
     class Meta:
         model=Post
-        exclude = ('user', 'like', 'timestamp', 'image')
+        exclude = ('user', 'like', 'timestamp', 'image','category')
         
\ No newline at end of file
