@@ -13,10 +13,6 @@ from django.utils.translation import ugettext_lazy as _
 from taggit.managers import TaggableManager
 from taggit.models import Tag
 
-class Category(models.Model):
-    name = models.CharField(max_length=100)
-    user = models.ForeignKey(User, related_name='cat_model')
-
 class Post(models.Model):
     #title = models.CharField(max_length=250, blank=True)
     text = models.TextField(blank=True, verbose_name=_('Text'))
@@ -27,7 +23,6 @@ class Post(models.Model):
     user = models.ForeignKey(User)
     like = models.IntegerField(default=0)
     url = models.CharField(blank=True, max_length=2000, validators=[URLValidator()])
-    category = models.ForeignKey(Category, null=True, blank=True, default=0)
     
     tags = TaggableManager(blank=True)
     
