@@ -20,12 +20,13 @@ from django.views.decorators.csrf import csrf_exempt
 import pin_image
 from pin.crawler import get_images
 from pin.forms import PinForm, PinUpdateForm
-from pin.models import Post, Follow, Stream, Likes, Notify, Category
+from pin.models import Post, Follow, Stream, Likes, Notify
 from pin.tools import create_filename
 
 from user_profile.models import Profile
 from taggit.models import Tag
 import sys
+from django.core.paginator import Paginator, PageNotAnInteger, EmptyPage
 
 MEDIA_ROOT = settings.MEDIA_ROOT
 
@@ -54,10 +55,39 @@ def home(request):
         return render_to_response('pin/home.html', 
                               {'latest_items': latest_items},
                               context_instance=RequestContext(request))
+
+def popular(request):
+    ROW_PER_PAGE = 20
+    
+    post_list = Post.objects.all().order_by('-like')
+    paginator = Paginator(post_list, ROW_PER_PAGE)
+    
+    
+    try:
+        offset = int(request.GET.get('older', 1))
+    except ValueError:
+        offset = 1
+    
+    try:
+        latest_items = paginator.page(offset)
+    except PageNotAnInteger:
+        latest_items = paginator.page(1)
+    except EmptyPage:
+        return HttpResponse(0)
+    
+    
+    form = PinForm()
+    
+    if request.is_ajax():
+        return render_to_response('pin/_items.html', 
+                              {'latest_items': latest_items,'pin_form':form,'offset':latest_items.next_page_number},
+                              context_instance=RequestContext(request))
+        
+    else:
+        return render_to_response('pin/home.html', 
+                              {'latest_items': latest_items, 'offset':latest_items.next_page_number},
+                              context_instance=RequestContext(request))
     
-    #return render_to_response('pin/home.html',context_instance=RequestContext(request))
-
-
 
 def user(request, user_id):
     user = get_object_or_404(User, pk=user_id)
@@ -187,22 +217,6 @@ def sendurl(request):
         if form.is_valid():
             model = form.save(commit=False)
             
-            category = post_values['category']
-            
-            if category.startswith('newcat-'):
-                category = category.replace('newcat-', '')
-                category, created = Category.objects.get_or_create(user=request.user,name=category)
-                category_id = category.id
-
-            elif int(category) == 0:
-                #category, created = Category.objects.get_or_create(user=request.user, name=u'ﺏﺩﻮﻧ ﺪﺴﺘﻫ ﺐﻧﺩی')
-                category_id = None
-            else:
-                category = Category.objects.filter(user=request.user, id=category).all()[0]
-                category_id = category.id
-                
-            model.category_id = category_id
-            
             image_url= model.image
             
             filename = image_url.split('/')[-1]
@@ -258,21 +272,6 @@ def send(request):
         if form.is_valid():
             model = form.save(commit=False)
             
-            category = post_values['category']
-             
-            if category.startswith('newcat-'):
-                category = category.replace('newcat-', '')
-                category, created = Category.objects.get_or_create(user=request.user,name=category)
-                category_id = category.id
-            elif  int(category) == 0:
-                #category, created = Category.objects.get_or_create(user=request.user, name=u'بدون دسته بندی')
-                category_id = None
-            else:
-                category = Category.objects.filter(user=request.user, id=category).all()
-                category_id = category.id
-                
-            model.category_id = category_id
-            
             filename= model.image
             
             image_o = "%s/pin/temp/o/%s" % ( MEDIA_ROOT,filename)
@@ -319,21 +318,6 @@ def edit(request, post_id):
             form = PinUpdateForm(post_values, instance=post)
             if form.is_valid():
                 model = form.save(commit=False)
-                category = post_values['category']
-                
-
-                if category.startswith('newcat-'):
-                    category = category.replace('newcat-', '')
-                    category, created = Category.objects.get_or_create(user=request.user,name=category)
-                    category_id = category.id
-                elif int(category) == 0:
-                    #category, created = Category.objects.get_or_create(user=request.user, name=u'ﺏﺩﻮﻧ ﺪﺴﺘﻫ ﺐﻧﺩی')
-                    category_id = None
-                else:
-                    category = Category.objects.filter(user=request.user, id=category).all()[0]
-                    category_id = category.id
-                    
-                model.category_id = category_id
                 
                 model.save()
                 
